@@ -8,6 +8,7 @@ import hashlib as hash
 from Crypto.Cipher import AES
 from Crypto.Cipher import Blowfish
 from Crypto.Protocol.KDF import PBKDF2
+from random import randbytes
 
 
 class Ciphers:
@@ -31,10 +32,29 @@ class Ciphers:
 
     # misc functions
 
+    def sec_delete(self, file_path, random_fill = True, null_fill = True, passes = 35) -> int:
+        if "/home/" not in file_path or "/." in file_path:
+            return 1
+        else:
+            with open (file_path, "wb") as file:
+                data = file.read()
+            length = len(data)
+            if random_fill is True:
+                for _ in passes:
+                    with open(file_path, "wb") as file:
+                        file.write(randbytes(length))
+            if null_fill is True:
+                for _ in passes:
+                    with open (file_path, "wb") as file:
+                        file.write("\x00" * length)
+            return 0
 
-    def log(self, logstring) -> int:
-        self.logger.log(logstring)
-        pass
+
+    def delete(self, path):
+        if '/home/' not in path or "/." in path:
+            return 1
+        else:
+            os.system("rm {}".format(path))
 
 
     def check_path_validity(self, path=str or None, decrypting=bool, type_=str) -> int:
@@ -110,15 +130,15 @@ class Ciphers:
         return (public_key, private_key)
 
 
-    def RSA_encrypt_str(self, public_key, string):
+    def RSA_encrypt_str(self, public_key, str_=str):
         "method to encrypt a string with a RSA public key."
-        encrypted_string = rsa.encrypt(string.encode(), public_key)
+        encrypted_string = rsa.encrypt(str_.encode(), public_key)
         return encrypted_string
 
 
-    def RSA_decrypt_str(self, private_key, encrypted_string):
+    def RSA_decrypt_str(self, private_key, encrypted_str):
         "Method to decrypt a string with a RSA private key."
-        decrypted_string = rsa.decrypt(encrypted_string, private_key).decode()
+        decrypted_string = rsa.decrypt(encrypted_str, private_key).decode()
         pass
 
 
@@ -260,7 +280,7 @@ class Ciphers:
     # Blowfish functions
 
 
-    def BLOencrypt(self, path=str):
+    def BLOencrypt_file(self, path=str):
         """
         A method for encrypting a file using the Blowfish encryption algorithm.
         """
@@ -303,7 +323,7 @@ class Ciphers:
                         file.write(ciphered_data)
 
 
-    def BLOdecrypt(self, path=str):
+    def BLOdecrypt_file(self, path=str):
         return_code = self.check_path_validity(path, decrypting=True, type_="BLO")
         if return_code != 0:
             return return_code
