@@ -35,6 +35,11 @@ class Log:
 
 
     def log(self, logstring = str) -> int:
-        with open ("") as file:
+        with open ("/home/{}/.log.log".format(self.username), "w") as file:
             file.write("{}\n".format(logstring))
-        pass
\ No newline at end of file
+        return 0
+    
+
+    def change_user(self, new_user=str) -> int:
+        self.username = new_user
+        return 0
\ No newline at end of file
