@@ -1,7 +1,7 @@
 from setuptools import setup, find_packages
 
-VERSION = "0.0.1"
-DESCRIPTION = "An AES encryption module."
+VERSION = "0.0.2"
+DESCRIPTION = "A module for encryption and information security operations."
 setup(
     name= "better cryptography",
     author = 'Wyatt Garrioch',
@@ -12,7 +12,7 @@ setup(
     long_description_content_type="text/markdown",
     packages = find_packages(),
     install_requires = ['pycryptodome', "rsa"],
-    keywords=["python", "encryption", "AES", "first package"],
+    keywords=["python", "encryption", "AES", "information security"],
     classifiers= [
         "Development Status :: 3 - Alpha",
         "Intended Audience :: Education",
